## 货币供应量

接口：cn_m

描述：获取货币供应量之月度数据

限量：单次最大5000，一次可以提取全部数据

权限：用户积累600积分可以使用，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| m | str | N | 月度（202001表示，2020年1月） |
| start_m | str | N | 开始月度 |
| end_m | str | N | 结束月度 |
| fields | str | N | 指定输出字段（e.g. fields='month,m0,m1,m2'） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| month | str | Y | 月份YYYYMM |
| m0 | float | Y | M0（亿元） |
| m0_yoy | float | Y | M0同比（%） |
| m0_mom | float | Y | M0环比（%） |
| m1 | float | Y | M1（亿元） |
| m1_yoy | float | Y | M1同比（%） |
| m1_mom | float | Y | M1环比（%） |
| m2 | float | Y | M2（亿元） |
| m2_yoy | float | Y | M2同比（%） |
| m2_mom | float | Y | M2环比（%） |

接口调用

```python
pro = ts.pro_api()
df = pro.cn_m(start_m='201901', end_m='202003')
#获取指定字段
df = pro.cn_m(start_m='201901', end_m='202003', fields='month,m0,m1,m2')
```

数据样例

```python
month        m0 m0_yoy m0_mom         m1 m1_yoy m1_mom          m2 m2_yoy m2_mom
0   202003  83000.00  10.80  -5.90  575100.00   5.00   4.05  2080900.00  10.10   2.47
```